[GHC] #4184: Squirrelly inliner behaviour leads to 80x slowdown
GHC
cvs-ghc at haskell.org
Tue Sep 14 13:47:38 EDT 2010
#4184: Squirrelly inliner behaviour leads to 80x slowdown
--------------------------------------+-------------------------------------
Reporter: bos | Owner:
Type: bug | Status: closed
Priority: normal | Milestone: 7.2.1
Component: Compiler | Version: 6.12.1
Resolution: invalid | Keywords:
Testcase: | Blockedby:
Difficulty: | Os: Unknown/Multiple
Blocking: | Architecture: Unknown/Multiple
Failure: Runtime performance bug |
--------------------------------------+-------------------------------------
Comment(by bos):
Under GHC 6.12, as comment #3 mentions, the INLINE doesn't really help
when enabled. It works for a trivial test case, so a tiny benchmark gets
sped back up, but in an application, the slowdown does not go away (i.e.
it looks like the inlining doesn't actually take place).
--
Ticket URL: <http://hackage.haskell.org/trac/ghc/ticket/4184#comment:11>
GHC <http://www.haskell.org/ghc/>
The Glasgow Haskell Compiler
More information about the Glasgow-haskell-bugs
mailing list